@@ -1,24 +1,21 @@
-# coding: utf-8
 """
     cairocffi.pixbuf
     ~~~~~~~~~~~~~~~~
 
     Loading various image formats with GDK-PixBuf
 
-    :copyright: Copyright 2013 by Simon Sapin
+    :copyright: Copyright 2013-2019 by Simon Sapin
     :license: BSD, see LICENSE for details.
 
 """
 
 import sys
-from io import BytesIO
-from functools import partial
 from array import array
+from functools import partial
+from io import BytesIO
 
-from . import dlopen, ImageSurface, Context, constants
-from ._ffi_pixbuf import ffi
-from .compat import xrange
-
+from . import Context, ImageSurface, constants, dlopen
+from ._generated.ffi_pixbuf import ffi
 
 __all__ = ['decode_to_image_surface']
 
@@ -52,7 +49,7 @@ def handle_g_error(error, return_value):
         if error.message != ffi.NULL:
             message = ('Pixbuf error: ' +
                        ffi.string(error.message).decode('utf8', 'replace'))
-        else:
+        else:  # pragma: no cover
             message = 'Pixbuf error'
         glib.g_error_free(error)
         raise ImageLoadingError(message)
@@ -100,7 +97,7 @@ def decode_to_pixbuf(image_data, width=None, height=None):
         if format_ != ffi.NULL else None)
 
     pixbuf = gdk_pixbuf.gdk_pixbuf_loader_get_pixbuf(loader)
-    if pixbuf == ffi.NULL:
+    if pixbuf == ffi.NULL:  # pragma: no cover
         raise ImageLoadingError('Not enough image data (got a NULL pixbuf.)')
     return Pixbuf(pixbuf), format_name
 
@@ -165,7 +162,7 @@ def pixbuf_to_cairo_slices(pixbuf):
     pixbuf_row_length = width * 3  # stride == row_length + padding
     cairo_row_length = width * 4  # stride == row_length + padding
     alpha = b'\xff' * width  # opaque
-    for y in xrange(height):
+    for y in range(height):
         offset = rowstride * y
         end = offset + pixbuf_row_length
         red = pixels[offset:end:3]
